/*
 Temperature Web Server
 
 A simple web server that shows the temperatures of LM35 analog input
 using an Arduino Wiznet Ethernet shield. 
 
 Circuit:
 * Ethernet shield attached to pins 10, 11, 12, 13
 * Temperature inputs attached to pins A0 through A5 (optional)
 
 created 18 Dec 2009
 by David A. Mellis
 modified 9 Apr 2012
 by Tom Igoe
 
 */
 
 /* YourDuino Multiple DS18B20 Temperature Sensors on 1 wire
  Connections:
  DS18B20 Pinout (Left to Right, pins down, flat side toward you)
  - Left   = Ground
  - Center = Signal (Pin 2):  (with 3.3K to 4.7K resistor to +5 or 3.3 )
  - Right  = +5 or +3.3 V

   Questions: terry@yourduino.com 
   V1.01  01/17/2013 ...based on examples from Rik Kretzinger
   
/*-----( Import needed libraries )-----*/

// Get 1-wire Library here: http://www.pjrc.com/teensy/td_libs_OneWire.html
#include <OneWire.h>

//Get DallasTemperature Library here:  http://milesburton.com/Main_Page?title=Dallas_Temperature_Control_Library
#include <DallasTemperature.h>

// ethernet libraries
#include <SPI.h>
#include <Ethernet.h>


/*-----( Declare Constants and Pin Numbers )-----*/
#define ONE_WIRE_BUS_PIN 2
float temperatura01 = 0;
float temperatura02 = 0;
float temperatura03 = 0;
float temperatura04 = 0;
float temperatura05 = 0;
float temperaturam01 = 0;
float temperaturam02 = 0;
float temperaturam03 = 0;
float temperaturam04 = 0;
float temperaturam05 = 0;
float alpha = 0.2;

/*-----( Declare objects )-----*/
// Setup a oneWire instance to communicate with any OneWire devices
OneWire oneWire(ONE_WIRE_BUS_PIN);

// Pass our oneWire reference to Dallas Temperature.
DallasTemperature sensors(&oneWire);

/*-----( Declare Variables )-----*/
// Assign the addresses of your 1-Wire temp sensors.
// See the tutorial on how to obtain these addresses:
// http://www.hacktronics.com/Tutorials/arduino-1-wire-address-finder.html

DeviceAddress Probe01 = { 0x28, 0xFF, 0x7B, 0x22, 0x52, 0x14, 0x00, 0xC1 }; 
DeviceAddress Probe02 = { 0x28, 0xFF, 0x6B, 0x0C, 0x52, 0x14, 0x00, 0xD8 };
DeviceAddress Probe03 = { 0x28, 0xFF, 0xC3, 0x19, 0x51, 0x14, 0x00, 0x88 };
DeviceAddress Probe04 = { 0x28, 0xFF, 0x0E, 0xF1, 0x51, 0x14, 0x00, 0x13 };
DeviceAddress Probe05 = { 0x28, 0xFF, 0x78, 0x24, 0x52, 0x14, 0x00, 0x86 };

// Enter a MAC address and IP address for your controller below.
// The IP address will be dependent on your local network:
byte mac[] = { 
  0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED };
IPAddress ip(192,168,12,201);
IPAddress gateway(192,168,12,1);
IPAddress subnet(255,255,255,0);
IPAddress dnserver(192,168,12,1);

// Initialize the Ethernet server library
// with the IP address and port you want to use 
// (port 80 is default for HTTP):
EthernetServer server(80);

void setup()   /****** SETUP: RUNS ONCE ******/ 
{
 // Open serial communications and wait for port to open:
  Serial.begin(9600);
//   while (!Serial) {
//    ; // wait for serial port to connect. Needed for Leonardo only
//  }
      Serial.print("Initializing Temperature Control Library Version ");
      Serial.println(DALLASTEMPLIBVERSION);

  // start the Ethernet connection and the server:
  Ethernet.begin(mac, ip, dnserver, gateway, subnet);

  // give the Ethernet shield a second to initialize:
  delay(1000); 
  server.begin();
  Serial.print("server is at ");
  Serial.println(Ethernet.localIP());

    // Initialize the Temperature measurement library
  sensors.begin();
  
  // set the resolution to 10 bit (Can be 9 to 12 bits .. lower is faster)
  sensors.setResolution(Probe01, 10);
  sensors.setResolution(Probe02, 10);
  sensors.setResolution(Probe03, 10);
  sensors.setResolution(Probe04, 10);
  sensors.setResolution(Probe05, 10);


}//--(end setup )---


void loop() {
  // listen for incoming clients
  EthernetClient client = server.available();
  if (client) {
    Serial.println("new client");
    // an http request ends with a blank line
    boolean currentLineIsBlank = true;
    while (client.connected()) {
      if (client.available()) {
        char c = client.read();
        Serial.write(c);
        // if you've gotten to the end of the line (received a newline
        // character) an  d the line is blank, the http request has ended,
        // so you can send a reply
        if (c == '\n' && currentLineIsBlank) {
          // send a standard http response header
          client.println("HTTP/1.1 200 OK");
          client.println("Content-Type: text/html");
          client.println("Connection: close");  // the connection will be closed after completion of the response
      client.println("Refresh: 5");  // refresh the page automatically every 5 sec
          client.println();
          client.println("<!DOCTYPE HTML>");
          client.println("<html>");


          // output the value of the DS18B20 sensors

          Serial.println();
          Serial.print("Number of Devices found on bus = ");  
          Serial.println(sensors.getDeviceCount());   
          Serial.print("Getting temperatures... ");  
          Serial.println();   
  
          // Command all devices on bus to read temperature  
          sensors.requestTemperatures();  
          temperatura01 = sensors.getTempC(Probe01); ///citeste temperatura de pe sonda Probe01
          temperatura02 = sensors.getTempC(Probe02); ///citeste temperatura de pe sonda Probe02
          temperatura03 = sensors.getTempC(Probe03); ///citeste temperatura de pe sonda Probe03
          temperatura04 = sensors.getTempC(Probe04); ///citeste temperatura de pe sonda Probe04
          temperatura05 = sensors.getTempC(Probe05); ///citeste temperatura de pe sonda Probe05

//            if (temperatura01 == -127.00)
//            {}
//            else
//            {
            temperaturam01 = temperatura01 * alpha + (1-alpha) * temperaturam01;
            client.print("<p><center>") ;
            client.print(temperaturam01);
            client.print(",");
            temperaturam02 = temperatura02 * alpha + (1-alpha) * temperaturam02;
            client.print(temperaturam02);
            client.print(",");
            temperaturam03 = temperatura03 * alpha + (1-alpha) * temperaturam03;
            client.print(temperaturam03);
            client.print(",");
            temperaturam04 = temperatura04 * alpha + (1-alpha) * temperaturam04;
            client.print(temperaturam04);
            client.print(",");
            temperaturam05 = temperatura05 * alpha + (1-alpha) * temperaturam05;
            client.print(temperaturam05);
            client.print(",</p>");
//            }
            
            client.print("<h1 style=\"text-align: center;\">Real-time room temperature.</h1>");
            client.print("<p>&nbsp;</p>");
            client.print("<p>&nbsp;</p>");
            client.print("<center>") ;
            client.print("<table style=\"width: 450px; height: 69px; background-color: #dcdcdc;\" border=\"5\">");

// Probe 01
            client.print("<tbody><tr><td><center><span style=\"color: black;\"><strong>T S 01_CT</strong></span></center></td>");
            client.print("<td><center><span style=\"color: black;\"><strong>");

            if (temperatura01 == -127.00)
            {
              client.println("Error");
              Serial.println("Error getting temperature ");
            }
            else
            {
              client.print(temperatura01);
              client.print(" - avg ");
              client.print(temperaturam01);
              client.print(" C");
              Serial.println("Probe 01 temperature is:  C ");
              Serial.print(temperatura01);
              Serial.print(" - ");
              Serial.println(temperaturam01);
            }
            client.print("</strong></span></td></tr>");

// Probe 02
            client.print("<tbody><tr><td><center><span style=\"color: black;\"><strong>T S 02_liv</strong></span></center></td>");
            client.print("<td><center><span style=\"color: black;\"><strong>");
            if (temperatura02 == -127.00)
            {
              client.println("Error");
              Serial.println("Error getting temperature ");
            }
            else
            {
              client.print(temperatura02);
              client.print(" - avg ");
              client.print(temperaturam02);
              client.print(" C");
              Serial.println("Probe 02 temperature is:  C ");
              Serial.print(temperatura02);
              Serial.print(" - ");
              Serial.println(temperaturam02);
            }
            client.print("</strong></span></td></tr>");

// Probe 03
            client.print("<tbody><tr><td><center><span style=\"color: black;\"><strong>T S 03_Adi</strong></span></center></td>");
            client.print("<td><center><span style=\"color: black;\"><strong>");
            if (temperatura03 == -127.00)
            {
              client.println("Error");
              Serial.println("Error getting temperature ");
            }
            else
            {
              client.print(temperatura03);
              client.print(" - avg ");
              client.print(temperaturam03);
              client.print(" C");
              Serial.println("Probe 03 temperature is:  C ");
              Serial.print(temperatura03);
              Serial.print(" - ");
              Serial.println(temperaturam03);
            }
            client.print("</strong></span></td></tr>");

// Probe 04
            client.print("<tbody><tr><td><center><span style=\"color: black;\"><strong>T S 04_hol_et</strong></span></center></td>");
            client.print("<td><center><span style=\"color: black;\"><strong>");
            if (temperatura04 == -127.00)
            {
              client.println("Error");
              Serial.println("Error getting temperature ");
            }
            else
            {
              client.print(temperatura04);
              client.print(" - avg ");
              client.print(temperaturam04);
              client.print(" C");
              Serial.println("Probe 04 temperature is:  C ");
              Serial.print(temperatura04);
              Serial.print(" - ");
              Serial.println(temperaturam04);
            }
            client.print("</strong></span></td></tr>");

// Probe 05
            client.print("<tbody><tr><td><center><span style=\"color: black;\"><strong>T S 05_man_cam</strong></span></center></td>");
            client.print("<td><center><span style=\"color: black;\"><strong>");
            if (temperatura05 == -127.00)
            {
              client.println("Error");
              Serial.println("Error getting temperature ");
            }
            else
            {
              client.print(temperatura05);
              client.print(" - avg ");
              client.print(temperaturam05);
              client.print(" C");
              Serial.println("Probe 05 temperature is:  C ");
              Serial.print(temperatura05);
              Serial.print(" - ");
              Serial.println(temperaturam05);
            }
            client.print("</strong></span></td></tr>");

            client.print("</tbody></table></center>");
            client.print("<h5 style=\"text-align: center;\">(C) Dan Padure 2014 DS18B20 webserver v0.42</h5>");
            

          client.println("</html>");
          break;
        }
        if (c == '\n') {
          // you're starting a new line
          currentLineIsBlank = true;
        } 
        else if (c != '\r') {
          // you've gotten a character on the current line
          currentLineIsBlank = false;
        }
      }
    }
    // give the web browser time to receive the data
    delay(1);
    // close the connection:
    client.stop();
    Serial.println("client disconnected");
  }
  else Serial.println ("no client");
  delay (1000);
}



